@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require './spec/cases/helper'
 require "active_record"
 
@@ -6,8 +7,8 @@ database = "parallel_with_ar_test"
 
 ActiveRecord::Schema.verbose = false
 ActiveRecord::Base.establish_connection(
-  :adapter => "mysql2",
-  :database => database
+  adapter: "mysql2",
+  database: database
 )
 
 class User < ActiveRecord::Base
@@ -15,7 +16,7 @@ end
 
 # create tables
 unless User.table_exists?
-  ActiveRecord::Schema.define(:version => 1) do
+  ActiveRecord::Schema.define(version: 1) do
     create_table :users do |t|
       t.string :name
     end
@@ -24,20 +25,20 @@ end
 
 User.delete_all
 
-User.create!(:name => "X")
+User.create!(name: "X")
 
 Parallel.map(1..8) do |i|
-  User.create!(:name => i)
+  User.create!(name: i)
 end
 
 puts "User.count: #{User.count}"
 
 puts User.connection.reconnect!.inspect
 
-Parallel.map(1..8, :in_threads => 4) do |i|
-  User.create!(:name => i)
+Parallel.map(1..8, in_threads: 4) do |i|
+  User.create!(name: i)
 end
 
-User.create!(:name => "X")
+User.create!(name: "X")
 
 puts User.all.map(&:name).sort.join("-")
