@@ -1,7 +1,8 @@
+# frozen_string_literal: true
 require './spec/cases/helper'
 
 process_diff do
-  result = Parallel.map([1,2,3,4], in_processes: 2, isolation: true) do |i|
+  result = Parallel.map([1, 2, 3, 4], in_processes: 2, isolation: true) do |_i|
     Parallel.worker_number
   end
   puts result.uniq.sort.join(',')
