@@ -1,18 +1,20 @@
+# frozen_string_literal: true
 require './spec/cases/helper'
 require 'stringio'
 
 class MyException < StandardError
   def initialize(object)
+    super()
     @object = object
   end
 end
 
 begin
   Parallel.in_processes(2) do
-    raise MyException.new(StringIO.new)
+    raise MyException, StringIO.new
   end
   puts "NOTHING WAS RAISED"
-rescue
+rescue StandardError
   puts $!.message
   puts "BACKTRACE: #{$!.backtrace.first}"
 end
