@@ -49,11 +49,6 @@ describe Parallel do
         (1..999).should include(Parallel.processor_count)
       end
     end
-
-    it 'uses Etc.nprocessors in Ruby 2.2+' do
-      defined?(Etc).should == "constant"
-      Etc.respond_to?(:nprocessors).should == true
-    end
   end
 
   describe ".physical_processor_count" do
@@ -144,7 +139,7 @@ describe Parallel do
         kill_process_with_name("spec/cases/parallel_fast_exit.rb") # simulates Ctrl+c
         sleep 1
         result = t.value
-        result.scan(/I finished/).size.should == 3
+        result.scan("I finished").size.should == 3
         result.should_not include("Parallel execution interrupted")
       end.should <= 4
     end
@@ -191,7 +186,6 @@ describe Parallel do
     end
 
     it 'does not leave processes behind while running' do
-      skip if ENV['TRAVIS'] # this randomly fails on travis all the time :(
       ruby("spec/cases/closes_processes_at_runtime.rb").gsub(/.* deprecated; use BigDecimal.*\n/, '').should == 'OK'
     end
 
@@ -335,18 +329,29 @@ describe Parallel do
 
       it "sets Parallel.worker_number with 0 #{type}" do
         skip if type == "ractors" # not supported
-        type_key = "in_#{type}".to_sym
+        type_key = :"in_#{type}"
         result = Parallel.map([1, 2, 3, 4, 5, 6, 7, 8, 9], type_key => 0) { |_x| Parallel.worker_number }
         result.uniq.should == [0]
         Parallel.worker_number.should be_nil
       end
 
-      it "can run with 0" do
+      it "can run with 0 by not using #{type}" do
         Thread.should_not_receive(:exclusive)
         Process.should_not_receive(:fork)
-        result = Parallel.map([1, 2, 3, 4, 5, 6, 7, 8, 9], "in_#{type}".to_sym => 0) { |x| x + 2 }
+        result = Parallel.map([1, 2, 3, 4, 5, 6, 7, 8, 9], "in_#{type}": 0) { |x| x + 2 }
         result.should == [3, 4, 5, 6, 7, 8, 9, 10, 11]
       end
+
+      it "can call finish hook in order #{type}" do
+        out = `METHOD=map WORKER_TYPE=#{type} ruby spec/cases/finish_in_order.rb 2>&1`
+        without_ractor_warning(out).should == <<~OUT
+          finish nil 0 nil
+          finish false 1 false
+          finish 2 2 "F2"
+          finish 3 3 "F3"
+          finish 4 4 "F4"
+        OUT
+      end
     end
 
     it "notifies when an item of work is dispatched to a worker process" do
@@ -499,7 +504,6 @@ describe Parallel do
     end
 
     it 'sets Parallel.worker_number when run with isolation' do
-      skip if ENV['TRAVIS'] # this randomly hangs on travis
       out = ruby("spec/cases/map_worker_number_isolation.rb")
       out.should == "0,1\nOK"
     end
@@ -540,6 +544,12 @@ describe Parallel do
     end
   end
 
+  describe ".filter_map" do
+    it "yields object" do
+      ruby("spec/cases/filter_map.rb 2>&1").should == '["a", "c"]'
+    end
+  end
+
   describe ".any?" do
     it "returns true if any result is truthy" do
       ruby("spec/cases/any_true.rb").split(',').should == ['true'] * 3 * 2
@@ -586,7 +596,7 @@ describe Parallel do
     end
 
     it "does not slow down with lots of GC work in threads" do
-      Benchmark.realtime { ruby("spec/cases/no_gc_with_each.rb 2>&1") }.should <= (ENV["TRAVIS"] ? 15 : 10)
+      Benchmark.realtime { ruby("spec/cases/no_gc_with_each.rb 2>&1") }.should <= 10
     end
 
     it "can modify in-place" do
@@ -721,13 +731,14 @@ describe Parallel do
     def normalize(result)
       result = result.sub(/\{(.*)\}/, "\\1").split(", ")
       result.reject! { |x| x =~ /^(Hash|Array|String)=>(1|-1|-2)$/ }
-      result.reject! { |x| x =~ /^(Mutex)=>(1)$/ } if RUBY_VERSION < "2.0"
+      result.reject! { |x| x =~ /^(Thread::Mutex)=>(1)$/ } if RUBY_VERSION >= "3.3"
       result
     end
 
     worker_types.each do |type|
       it "does not leak memory in #{type}" do
         pending if RUBY_ENGINE == 'jruby' # lots of objects ... GC does not seem to work ...
+        skip if RUBY_VERSION > "3.4.0" # randomly fails, so can't use pending
         options = (RUBY_ENGINE == 'jruby' ? "-X+O" : "")
         result = ruby("#{options} spec/cases/profile_memory.rb #{type} 2>&1").strip.split("\n").last
         normalize(result).should == []
