@@ -1,3 +1,4 @@
+# frozen_string_literal: true
 require 'parallel'
 require 'benchmark'
 require 'timeout'
@@ -6,4 +7,11 @@ RSpec.configure do |config|
   config.expect_with(:rspec) { |c| c.syntax = :should }
   config.mock_with(:rspec) { |c| c.syntax = :should }
   config.around { |example| Timeout.timeout(30, &example) }
+  config.include(
+    Module.new do
+      def ruby(cmd)
+        `#{RbConfig.ruby} #{cmd}`
+      end
+    end
+  )
 end
